==> haskell-yesod-persistent-1.6.0.2-67-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.6.0.2
id: yesod-persistent-1.6.0.2-CGtfbr0LU2acmqJJPetG9
key: yesod-persistent-1.6.0.2-CGtfbr0LU2acmqJJPetG9
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
abi: 2969d71352d02228b3bbf139bc8b5223
exposed: True
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-persistent-1.6.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-persistent-1.6.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-persistent-1.6.0.2
hs-libraries: HSyesod-persistent-1.6.0.2-CGtfbr0LU2acmqJJPetG9
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    conduit-1.3.1.1-3gq47figCcD3FXjYab6brY
    persistent-2.10.0-5TmQDzXKJWKAJCRYTAW1bm
    persistent-template-2.7.2-Jkb8AjMf4V9KqzZdRsTeHk
    resource-pool-0.2.3.2-IAoyPiFBos586Bxmdqt9IZ
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq transformers-0.5.6.2
    yesod-core-1.6.14-LDhycdhz7aB4O53Gk9ahIP
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.6.0.2-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.6.0.2
id: yesod-persistent-1.6.0.2-FO3rOL1IsNdBCAFUpdTCl9
key: yesod-persistent-1.6.0.2-FO3rOL1IsNdBCAFUpdTCl9
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
abi: cd5457df6dfe7a606c87a68dd85d86c0
exposed: True
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-persistent-1.6.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-persistent-1.6.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-persistent-1.6.0.2
hs-libraries: HSyesod-persistent-1.6.0.2-FO3rOL1IsNdBCAFUpdTCl9
depends:
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    conduit-1.3.1.1-3gq47figCcD3FXjYab6brY
    persistent-2.10.0-F4CPpPaYOvl8cb6reliVex
    persistent-template-2.7.2-FZcJMgY6L7o7fvL9CPjaAC
    resource-pool-0.2.3.2-IAoyPiFBos586Bxmdqt9IZ
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq transformers-0.5.6.2
    yesod-core-1.6.14-Bz31HlCM7Qc9sRGPGsG4xj
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
